OC.L10N.register(
    "lib",
    {
    "today" : "بۈگۈن",
    "yesterday" : "تۈنۈگۈن",
    "None" : "يوق",
    "Username" : "ئىشلەتكۈچى ئاتى",
    "Password" : "ئىم",
    "Apps" : "ئەپلەر",
    "General" : "ئادەتتىكى",
    "Storage" : "ساقلىغۇچ",
    "Security" : "بىخەتەرلىك",
    "Encryption" : "شىفىرلاش",
    "Sharing" : "ھەمبەھىر",
    "Search" : "ئىزدە",
    "A valid username must be provided" : "چوقۇم ئىناۋەتلىك ئىشلەتكۈچى ئىسمىدىن بىرنى تەمىنلەش كېرەك",
    "A valid password must be provided" : "چوقۇم ئىناۋەتلىك ئىم تەمىنلەش كېرەك",
    "Help" : "ياردەم",
    "Settings" : "تەڭشەكلەر",
    "Users" : "ئىشلەتكۈچىلەر",
    "Authentication error" : "سالاھىيەت دەلىللەش خاتالىقى",
    "__language_name__" : "ئۇيغۇرچە"
},
"nplurals=1; plural=0;");
